@@ -13,7 +13,8 @@ Example:
                     ["Mr\\nXavier\\nHuon", 32, "Xav'"],
                     ["Mr\\nBaptiste\\nClement", 1, "Baby"],
                     ["Mme\\nLouise\\nBourgeau", 28, "Lou\\n\\nLoue"]])
-    print table.draw() + "\\n"
+    print(table.draw())
+    print()
 
     table = Texttable()
     table.set_deco(Texttable.HEADER)
@@ -28,7 +29,7 @@ Example:
                     ["efghijk", 67.5434, .654,  89.6,  12800000000000000000000.00023],
                     ["lmn",     5e-78,   5e-78, 89.4,  .000000000000128],
                     ["opqrstu", .023,    5e+78, 92.,   12800000000000000000000]])
-    print table.draw()
+    print(table.draw())
 
 Result:
 
@@ -62,7 +63,7 @@ __all__ = ["Texttable", "ArraySizeError"]
 
 __author__ = 'Gerome Fournier <jef(at)foutaise.org>'
 __license__ = 'MIT'
-__version__ = '1.6.3'
+__version__ = '1.6.4'
 __credits__ = """\
 Jeff Kowalczyk:
     - textwrap improved import
@@ -246,7 +247,7 @@ class Texttable:
     def set_deco(self, deco):
         """Set the table decoration
 
-        - 'deco' can be a combinaison of:
+        - 'deco' can be a combination of:
 
             Texttable.BORDER: Border around the table
             Texttable.HEADER: Horizontal line below the header
@@ -261,6 +262,7 @@ class Texttable:
         """
 
         self._deco = deco
+        self._hline_string = None
         return self
 
     def set_header_align(self, array):
@@ -724,7 +726,8 @@ if __name__ == '__main__':
                     ["Mr\nXavier\nHuon", 32, "Xav'"],
                     ["Mr\nBaptiste\nClement", 1, "Baby"],
                     ["Mme\nLouise\nBourgeau", 28, "Lou\n \nLoue"]])
-    print(table.draw() + "\n")
+    print(table.draw())
+    print()
 
     table = Texttable()
     table.set_deco(Texttable.HEADER)
